sndict Documentation
====================


.. include:: ../README.rst


Contents:
=========

.. toctree::
   :maxdepth: 5

   readme
   examples
   ndict
   sndict
   app
   installation
   usage
   contributing
   authors
   history
